==> apache-dolphinscheduler-2.0.2-src.tar.gz: apache-dolphinscheduler-2.0.2-src/dolphinscheduler-api/src/test/java/org/apache/dolphinscheduler/api/configuration/TrafficConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.api.configuration;

import org.apache.dolphinscheduler.api.controller.AbstractControllerTest;

import org.apache.commons.collections.MapUtils;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

public class TrafficConfigurationTest extends AbstractControllerTest {

    @Autowired
    private TrafficConfiguration trafficConfiguration;

    @Test
    public void isTrafficGlobalControlSwitch() {
        Assert.assertFalse(trafficConfiguration.isTrafficGlobalControlSwitch());
    }

    @Test
    public void getMaxGlobalQpsLimit() {
        Assert.assertEquals(300, (int) trafficConfiguration.getMaxGlobalQpsRate());
    }

    @Test
    public void isTrafficTenantControlSwitch() {
        Assert.assertFalse(trafficConfiguration.isTrafficTenantControlSwitch());
    }

    @Test
    public void getDefaultTenantQpsLimit() {
        Assert.assertEquals(10, (int) trafficConfiguration.getDefaultTenantQpsRate());
    }

    @Test
    public void getCustomizeTenantQpsRate() {
        Assert.assertTrue(MapUtils.isEmpty(trafficConfiguration.getCustomizeTenantQpsRate()));
    }
}

==> apache-dolphinscheduler-3.0.6-src.tar.gz: apache-dolphinscheduler-3.0.6-src/dolphinscheduler-api/src/test/java/org/apache/dolphinscheduler/api/configuration/TrafficConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.api.configuration;

import org.apache.dolphinscheduler.api.controller.AbstractControllerTest;

import org.apache.commons.collections.MapUtils;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

public class TrafficConfigurationTest extends AbstractControllerTest {

    @Autowired
    private TrafficConfiguration trafficConfiguration;

    @Test
    public void isTrafficGlobalControlSwitch() {
        Assert.assertFalse(trafficConfiguration.isGlobalSwitch());
    }

    @Test
    public void getMaxGlobalQpsLimit() {
        Assert.assertEquals(300, (int) trafficConfiguration.getMaxGlobalQpsRate());
    }

    @Test
    public void isTrafficTenantControlSwitch() {
        Assert.assertFalse(trafficConfiguration.isTenantSwitch());
    }

    @Test
    public void getDefaultTenantQpsLimit() {
        Assert.assertEquals(10, (int) trafficConfiguration.getDefaultTenantQpsRate());
    }

    @Test
    public void getCustomizeTenantQpsRate() {
        Assert.assertTrue(MapUtils.isEmpty(trafficConfiguration.getCustomizeTenantQpsRate()));
    }
}
